pub struct BloomFilter { /* private fields */ }Expand description
Bloom Filter - Probabilistic membership test
Space-efficient set membership test with no false negatives but possible false positives (configurable error rate).
Implementations
Sourceimpl BloomFilter
impl BloomFilter
Sourcepub fn new(size: usize, hash_count: usize) -> Self
pub fn new(size: usize, hash_count: usize) -> Self
Create a new Bloom filter
Arguments
size- Number of bits in the filterhash_count- Number of hash functions
Optimal hash_count = (bits / expected_items) * ln(2)
Sourcepub fn optimal(expected_items: usize, false_positive_rate: f64) -> Self
pub fn optimal(expected_items: usize, false_positive_rate: f64) -> Self
Optimal Bloom filter for expected items and false positive rate
Sourcepub fn false_positive_rate(&self) -> f64
pub fn false_positive_rate(&self) -> f64
Estimate current false positive rate
Sourcepub fn stats(&self) -> BloomFilterStats
pub fn stats(&self) -> BloomFilterStats
Get statistics about the Bloom filter