pub struct ConsistentHashRouter { /* private fields */ }Expand description
Routes stream partitions to nodes using consistent hashing.
Uses a hash ring with configurable virtual nodes per physical node to achieve even load distribution and minimal partition movement on topology changes.
Implementations
Sourceimpl ConsistentHashRouter
impl ConsistentHashRouter
Sourcepub fn new(virtual_nodes_per_node: usize) -> Self
pub fn new(virtual_nodes_per_node: usize) -> Self
Creates a new router with the specified number of virtual nodes per physical node.
Sourcepub fn add_node(&mut self, node: StreamNode)
pub fn add_node(&mut self, node: StreamNode)
Adds a node to the hash ring.
Sourcepub fn remove_node(&mut self, node_id: &str) -> DistributedResult<()>
pub fn remove_node(&mut self, node_id: &str) -> DistributedResult<()>
Removes a node from the hash ring.
Sourcepub fn route(&self, partition_key: &str) -> DistributedResult<&StreamNode>
pub fn route(&self, partition_key: &str) -> DistributedResult<&StreamNode>
Routes a partition key to the responsible node.
Sourcepub fn nodes(&self) -> impl Iterator<Item = &StreamNode>
pub fn nodes(&self) -> impl Iterator<Item = &StreamNode>
Returns an iterator over all known physical nodes.
Sourcepub fn node_count(&self) -> usize
pub fn node_count(&self) -> usize
Returns the number of physical nodes.