pub struct CrdtEventLog { /* private fields */ }Expand description
A CRDT-based distributed event log.
Combines a G-Counter (total events), a PN-Counter (net activity), and LWW-Register entries to provide a causally consistent log across nodes.
Implementations
Sourceimpl CrdtEventLog
impl CrdtEventLog
Sourcepub fn new(node_id: impl Into<String>) -> Self
pub fn new(node_id: impl Into<String>) -> Self
Creates a new CRDT event log for the given node.
Sourcepub fn append(&self, payload: Vec<u8>) -> u64
pub fn append(&self, payload: Vec<u8>) -> u64
Appends an event to the log, returning the assigned sequence number.
Sourcepub fn record_removal(&self)
pub fn record_removal(&self)
Records a removal (decrement) event without removing from the immutable log.
Sourcepub fn set_register(&self, key: &str, value: Vec<u8>)
pub fn set_register(&self, key: &str, value: Vec<u8>)
Writes a named LWW-Register value.
Sourcepub fn merge_remote(&self, remote: &RemoteCrdtState)
pub fn merge_remote(&self, remote: &RemoteCrdtState)
Merges a remote CRDT event log state into this log.
Sourcepub fn export_state(&self) -> RemoteCrdtState
pub fn export_state(&self) -> RemoteCrdtState
Exports current state for transmission to remote nodes.
Sourcepub fn stats(&self) -> CrdtEventLogStats
pub fn stats(&self) -> CrdtEventLogStats
Returns CRDT event log statistics.
Sourcepub fn entries(&self) -> Vec<CrdtLogEntry>
pub fn entries(&self) -> Vec<CrdtLogEntry>
Returns all log entries in sequence order.