pub struct EventFilter;Expand description
Applies FilterPredicates to slices of StreamEvents.
This is a stateless utility struct — all methods are pure functions.
Implementations
Sourceimpl EventFilter
impl EventFilter
Sourcepub fn filter<'a>(
&self,
events: &'a [StreamEvent],
predicate: &FilterPredicate,
) -> Vec<&'a StreamEvent>
pub fn filter<'a>( &self, events: &'a [StreamEvent], predicate: &FilterPredicate, ) -> Vec<&'a StreamEvent>
Return references to all events in events that satisfy predicate.
Sourcepub fn count(
&self,
events: &[StreamEvent],
predicate: &FilterPredicate,
) -> usize
pub fn count( &self, events: &[StreamEvent], predicate: &FilterPredicate, ) -> usize
Return the count of events that satisfy predicate.
Sourcepub fn any(&self, events: &[StreamEvent], predicate: &FilterPredicate) -> bool
pub fn any(&self, events: &[StreamEvent], predicate: &FilterPredicate) -> bool
Return true if at least one event satisfies predicate.
Sourcepub fn all(&self, events: &[StreamEvent], predicate: &FilterPredicate) -> bool
pub fn all(&self, events: &[StreamEvent], predicate: &FilterPredicate) -> bool
Return true if every event satisfies predicate.
Returns true for an empty slice (vacuous truth).