Module lib_types_patch

Module lib_types_patch 

RDF patch types and unified Stream interface

Structs

RdfPatch
RDF patch for atomic updates with full protocol support
Stream
Unified Stream interface that combines producer and consumer functionality

Enums

PatchOperation
RDF patch operations with full protocol support

Functions

publish_patch
Standalone helper: publish an RDF patch via a StreamProducer