pub struct StreamAnomalyDetector { /* private fields */ }Expand description
Z-score based streaming anomaly detector with a sliding window.
Maintains a sliding window of recent values, computes running mean and standard deviation, and flags values whose Z-score exceeds the configured sigma threshold.
Implementations
Sourceimpl StreamAnomalyDetector
impl StreamAnomalyDetector
Sourcepub fn new(config: AnomalyDetectorConfig) -> Self
pub fn new(config: AnomalyDetectorConfig) -> Self
Creates a new anomaly detector.
Sourcepub fn is_anomaly(&self, value: f64) -> AnomalyCheckResult
pub fn is_anomaly(&self, value: f64) -> AnomalyCheckResult
Checks whether a value is anomalous.
Sourcepub fn stats(&self) -> AnomalyDetectorStats
pub fn stats(&self) -> AnomalyDetectorStats
Returns detector statistics.
Sourcepub fn effective_threshold(&self) -> f64
pub fn effective_threshold(&self) -> f64
Returns the current effective threshold.