pub struct MemoryHandle { /* private fields */ }Expand description
Handle for allocated memory
Implementations
Sourceimpl MemoryHandle
impl MemoryHandle
Sourcepub unsafe fn as_slice(&self) -> &[u8] ⓘ
pub unsafe fn as_slice(&self) -> &[u8] ⓘ
Get a slice view of the allocated memory
Safety
The caller must ensure that the memory block is properly initialized and that the returned slice is not accessed after the block is deallocated
Sourcepub unsafe fn as_mut_slice(&mut self) -> &mut [u8] ⓘ
pub unsafe fn as_mut_slice(&mut self) -> &mut [u8] ⓘ
Get a mutable slice view of the allocated memory
Safety
The caller must ensure that the memory block is properly initialized and that the returned slice is not accessed after the block is deallocated