pub struct ExactlyOnceProcessor { /* private fields */ }Expand description
Wraps a state backend and deduplication log to provide exactly-once processing guarantees.
Implementations
Sourceimpl ExactlyOnceProcessor
impl ExactlyOnceProcessor
Sourcepub fn new(config: DeduplicationConfig, backend: Arc<dyn StateBackend>) -> Self
pub fn new(config: DeduplicationConfig, backend: Arc<dyn StateBackend>) -> Self
Create a new processor.
Sourcepub fn process<R, F>(
&mut self,
id: MessageId,
processor: F,
) -> Result<Option<R>, StreamError>
pub fn process<R, F>( &mut self, id: MessageId, processor: F, ) -> Result<Option<R>, StreamError>
Process a message exactly once.
If id has already been processed within the deduplication window the
closure is NOT invoked and Ok(None) is returned.
Otherwise the closure is called with a fresh transaction. The closure
is expected to add state changes to the transaction; this method then
commits it and returns Ok(Some(result)).
Sourcepub fn maintenance(&mut self) -> usize
pub fn maintenance(&mut self) -> usize
Perform maintenance: evict expired dedup entries.
Sourcepub fn stats(&self) -> ExactlyOnceStats
pub fn stats(&self) -> ExactlyOnceStats
Statistics about this processor.