pub struct LateDataHandler {
pub policy: LateDataPolicy,
pub late_event_count: u64,
}Expand description
Applies the configured LateDataPolicy to late events.
Fields
policy: LateDataPolicylate_event_count: u64Implementations
Sourceimpl LateDataHandler
impl LateDataHandler
Sourcepub fn new(policy: LateDataPolicy) -> Self
pub fn new(policy: LateDataPolicy) -> Self
Create a handler with the given policy.
Sourcepub fn handle(
&mut self,
event_ts_ms: i64,
watermark_ms: i64,
) -> LateDataDecision
pub fn handle( &mut self, event_ts_ms: i64, watermark_ms: i64, ) -> LateDataDecision
Decide what to do with an event at event_ts_ms given that the
current watermark is watermark_ms.
If event_ts_ms >= watermark_ms the event is not late and Process is returned.