pub struct StreamWatermark {
pub timestamp: i64,
pub source_id: String,
pub advance_count: u64,
}Expand description
An event-time watermark generated by a single source.
The watermark asserts that all future events from source_id will have
timestamps >= timestamp.
Fields
timestamp: i64Milliseconds since Unix epoch.
source_id: StringIdentifier of the source that produced this watermark.
advance_count: u64Number of times this generator has advanced the watermark.
Implementations