pub struct WindowAlgebra<T: Clone> { /* private fields */ }Expand description
The main stream windowing algebra operator.
Generic over the event payload type T.
Implementations
Sourceimpl<T: Clone> WindowAlgebra<T>
impl<T: Clone> WindowAlgebra<T>
Sourcepub fn new(config: WindowAlgebraConfig) -> Self
pub fn new(config: WindowAlgebraConfig) -> Self
Create a new windowing operator with the given configuration.
Sourcepub fn with_late_policy(self, policy: LatePolicy) -> Self
pub fn with_late_policy(self, policy: LatePolicy) -> Self
Set the late data policy.
Sourcepub fn with_max_open_windows(self, max: usize) -> Self
pub fn with_max_open_windows(self, max: usize) -> Self
Set the maximum number of open windows.
Sourcepub fn stats(&self) -> &WindowAlgebraStats
pub fn stats(&self) -> &WindowAlgebraStats
Get current statistics.
Sourcepub fn watermark_ms(&self) -> i64
pub fn watermark_ms(&self) -> i64
Get current watermark in milliseconds.
Sourcepub fn open_pane_count(&self) -> usize
pub fn open_pane_count(&self) -> usize
Get the number of currently open panes.
Sourcepub fn drain_side_output(&mut self) -> Vec<WindowEvent<T>>
pub fn drain_side_output(&mut self) -> Vec<WindowEvent<T>>
Get the side output (late events).
Sourcepub fn advance_watermark(&mut self, watermark_ms: i64) -> Vec<WindowOutput<T>>
pub fn advance_watermark(&mut self, watermark_ms: i64) -> Vec<WindowOutput<T>>
Advance the watermark and return any windows that should be closed.
Sourcepub fn ingest(&mut self, event: WindowEvent<T>) -> Vec<WindowOutput<T>>
pub fn ingest(&mut self, event: WindowEvent<T>) -> Vec<WindowOutput<T>>
Ingest a single event. Returns any triggered window outputs.
Sourcepub fn ingest_batch(
&mut self,
events: Vec<WindowEvent<T>>,
) -> Vec<WindowOutput<T>>
pub fn ingest_batch( &mut self, events: Vec<WindowEvent<T>>, ) -> Vec<WindowOutput<T>>
Ingest a batch of events.
Sourcepub fn flush(&mut self) -> Vec<WindowOutput<T>>
pub fn flush(&mut self) -> Vec<WindowOutput<T>>
Flush all open windows, emitting their contents.