pub struct WindowResult {
pub windows: Vec<Window>,
pub total_points: usize,
}Expand description
Result of applying a window function to a data stream.
Fields
windows: Vec<Window>All produced windows (may include empty windows for tumbling/sliding).
total_points: usizeTotal number of data points processed across all windows.