pub struct ConsistencyManager { /* private fields */ }Expand description
Enforces per-session monotonic-read and monotonic-write guarantees.
Sessions are identified by arbitrary string tokens (e.g., client IDs).
Implementations
Sourceimpl ConsistencyManager
impl ConsistencyManager
Sourcepub fn new(config: ConsistencyConfig) -> Self
pub fn new(config: ConsistencyConfig) -> Self
Create a new manager with the given configuration.
Sourcepub fn can_read<T>(
&mut self,
session_id: &str,
value: &VersionedValue<T>,
) -> bool
pub fn can_read<T>( &mut self, session_id: &str, value: &VersionedValue<T>, ) -> bool
Determine whether a read of value is acceptable for session_id.
Eventual/ReadYourWrites/Strong/Linearizable: alwaystrueMonotonicRead:value.version >= session's last-seen version
Sourcepub fn after_read<T>(&mut self, session_id: &str, value: &VersionedValue<T>)
pub fn after_read<T>(&mut self, session_id: &str, value: &VersionedValue<T>)
Record that session_id has observed value (update monotonic-read floor).
Sourcepub fn can_write<T>(
&mut self,
session_id: &str,
value: &VersionedValue<T>,
) -> bool
pub fn can_write<T>( &mut self, session_id: &str, value: &VersionedValue<T>, ) -> bool
Determine whether a write of value is valid for session_id.
MonotonicWrite:value.version >= session's last-write version- everything else: always
true
Sourcepub fn after_write<T>(&mut self, session_id: &str, value: &VersionedValue<T>)
pub fn after_write<T>(&mut self, session_id: &str, value: &VersionedValue<T>)
Record that session_id performed a write at value’s version.
Sourcepub fn is_stale<T>(
&self,
value: &VersionedValue<T>,
current_version: u64,
) -> bool
pub fn is_stale<T>( &self, value: &VersionedValue<T>, current_version: u64, ) -> bool
Return true if value.version is strictly behind current_version
(i.e., the value is stale).
Sourcepub fn config(&self) -> &ConsistencyConfig
pub fn config(&self) -> &ConsistencyConfig
Reference to the active configuration.
Sourcepub fn monotonic_read_session_count(&self) -> usize
pub fn monotonic_read_session_count(&self) -> usize
How many sessions are tracked for monotonic-read.
Sourcepub fn monotonic_write_session_count(&self) -> usize
pub fn monotonic_write_session_count(&self) -> usize
How many sessions are tracked for monotonic-write.