pub struct MessageTransformer { /* private fields */ }Expand description
Registry of named transformation pipelines.
Example
use oxirs_stream::message_transformer::*;
use std::collections::HashMap;
let mut transformer = MessageTransformer::new();
let pipeline = TransformPipeline::new(
MessageFormat::Json,
MessageFormat::Avro,
vec![FieldMapping::with_transform("name", "NAME", TransformFn::ToUpper)],
);
transformer.add_pipeline("upper", pipeline);
let mut fields = HashMap::new();
fields.insert("name".to_string(), "alice".to_string());
let payload = MessagePayload::new(fields, MessageFormat::Json);
let result = transformer.transform("upper", payload)?;
assert_eq!(result.fields["NAME"], "ALICE");Implementations
Sourceimpl MessageTransformer
impl MessageTransformer
Sourcepub fn add_pipeline(&mut self, name: &str, pipeline: TransformPipeline)
pub fn add_pipeline(&mut self, name: &str, pipeline: TransformPipeline)
Register a named pipeline. Overwrites any existing pipeline with the same name.
Sourcepub fn transform(
&self,
pipeline_name: &str,
payload: MessagePayload,
) -> Result<MessagePayload, TransformError>
pub fn transform( &self, pipeline_name: &str, payload: MessagePayload, ) -> Result<MessagePayload, TransformError>
Apply the named pipeline to payload.
Each FieldMapping in the pipeline is applied in order:
- The value of
source_fieldis read from the payload. - The optional
TransformFnis applied. - The result is stored under
target_fieldin the output payload.
Fields present in the payload but not mentioned by any mapping are dropped.
Sourcepub fn chain_pipelines(
&self,
names: &[&str],
payload: MessagePayload,
) -> Result<MessagePayload, TransformError>
pub fn chain_pipelines( &self, names: &[&str], payload: MessagePayload, ) -> Result<MessagePayload, TransformError>
Apply a sequence of pipelines in order.
The output of each pipeline is fed as the input to the next. The format of the intermediate payloads is updated by each pipeline.
Sourcepub fn list_pipelines(&self) -> Vec<&str>
pub fn list_pipelines(&self) -> Vec<&str>
Return the names of all registered pipelines (order unspecified).
Sourcepub fn pipeline_count(&self) -> usize
pub fn pipeline_count(&self) -> usize
Return the number of registered pipelines.
Sourcepub fn has_pipeline(&self, name: &str) -> bool
pub fn has_pipeline(&self, name: &str) -> bool
Check whether a pipeline with the given name exists.
Sourcepub fn remove_pipeline(&mut self, name: &str) -> bool
pub fn remove_pipeline(&mut self, name: &str) -> bool
Remove a pipeline by name. Returns true if it was present.