Adaptive batching for performance optimization
This module provides adaptive batching capabilities to optimize throughput and latency by dynamically adjusting batch sizes based on system performance.
Structs
- Adaptive
Batcher - Adaptive batcher for events
- Batch
Performance Point - Performance data point for batch processing
- Batch
Size Predictor - Batch size predictor using historical performance data
- Batching
Stats - Batching statistics