pub struct DatasetEventBus { /* private fields */ }Expand description
An in-process publish-subscribe bus for RDF dataset change events.
Multiple ChangeSubscriber implementations can be registered. When
DatasetEventBus::publish is called every subscriber receives the event
in registration order. Errors from individual subscribers are collected
but do not prevent later subscribers from receiving the event.
Implementations
Sourceimpl DatasetEventBus
impl DatasetEventBus
Sourcepub fn subscribe(&mut self, subscriber: Box<dyn ChangeSubscriber>)
pub fn subscribe(&mut self, subscriber: Box<dyn ChangeSubscriber>)
Register a subscriber.
Sourcepub fn publish(&self, event: DatasetChangeEvent) -> Result<()>
pub fn publish(&self, event: DatasetChangeEvent) -> Result<()>
Publish a change event to all registered subscribers.
All subscribers are called even if earlier ones return an error. If any subscriber failed the first error is returned.
Sourcepub fn subscriber_count(&self) -> usize
pub fn subscriber_count(&self) -> usize
Return the number of registered subscribers.